@@ -61,7 +61,7 @@ CSAMiningProcess <- function (D,DS,w,a,sb,tb,si,ka){
 NormSAX <- function (D,a){
   vector <- as.matrix(D)
   vector <- as.vector(vector)
-  vectorNorm <- (vector-mean(vector, na.rm = T))/sd(vector, na.rm = T)
+  vectorNorm <- (vector-mean(vector, na.rm = T))/stats::sd(vector, na.rm = T)
   DS <- STSSaxEncode(D, vectorNorm, a)
   return (DS)
 }
